###############################################################################
# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
"""
Example of a DaVinci job printing decay trees via `PrintDecayTree`.
"""

__author__ = "Eduardo Rodrigues"
__date__ = "2021-03-02"

from PyConf.application import configure, configure_input
from PyConf.control_flow import CompositeNode, NodeLogic
from PyConf.Algorithms import PrintDecayTree

from DaVinci import options
from DaVinci.reco_objects import upfront_reconstruction_from_file as upfront_reconstruction
from DaVinci.common_particles import make_std_loose_jpsi2mumu

# Following line sets options data_type, simulation and DB tags, and the inputs
options.set_input_and_conds_from_testfiledb("Upgrade_Bd2KstarMuMu")
options.evt_max = 100
options.print_freq = 1
options.msg_svc_format = "% F%40W%S%7W%R%T %0W%M"

jpsis = make_std_loose_jpsi2mumu()

pdt = PrintDecayTree(name="PrintJpsis", Input=jpsis)

# the "upfront_reconstruction" is what unpacks reconstruction objects, particles and primary vertices
# from file and creates protoparticles.
algs = upfront_reconstruction() + [jpsis, pdt]

node = CompositeNode(
    "PrintJpsiNode", children=algs, combine_logic=NodeLogic.NONLAZY_AND)

config = configure_input(options)
config.update(configure(options, node))
