###############################################################################
# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
"""
Example of a typical DaVinci job:
 - selection of two detached opposite-charge muons
 - tuple of the selected candidates

 This example is meant to be run with
    $ ./run davinci run-mc --simplejob --inputfiledb Upgrade_Bd2KstarMuMu --joboptfile example-tupling-basic.yaml --user_algorithms example-tupling-basic-run-mc:main
"""

__author__ = "Maurizio Martinelli, Abhijit Mathad"
__date__ = "2021-05-03"

import Functors as F
from DaVinci.standard_particles import make_detached_mumu
from DaVinci.reco_objects import upfront_reconstruction_from_file as upfront_reconstruction
from FunTuple import FunctorCollection
from FunTuple import FunTuple_Particles as Funtuple

# Prepare the node with the selection
dimuons = make_detached_mumu()

#FunTuple: Jpsi info
fields = {}
fields['Jpsi'] = 'J/psi(1S) -> mu+ mu-'
fields['MuPlus'] = 'J/psi(1S) -> ^mu+ mu-'

#make collection of functors for Jpsi
variables_jpsi = FunctorCollection({
    'LOKI_P':
    'P',
    'LOKI_PT':
    'PT',
    'LOKI_Muonp_PT':
    'CHILD(PT, 1)',
    'LOKI_Muonm_PT':
    'CHILD(PT, 2)',
    'LOKI_MAXPT':
    'TRACK_MAX_PT',
    'LOKI_N_HIGHPT_TRCKS':
    'NINTREE(ISBASIC & HASTRACK & (PT > 1500*MeV))',
    'THOR_P':
    F.P,
    'THOR_PT':
    F.PT
})

#make collection of functors for Muplus
variables_muplus = FunctorCollection({'LOKI_P': 'P', 'THOR_P': F.P})

#associate FunctorCollection to (field branch) name
variables = {}
variables['Jpsi'] = variables_jpsi
variables['MuPlus'] = variables_muplus

#FunTuple: define list of preambles for loki
loki_preamble = ['TRACK_MAX_PT = MAXTREE(ISBASIC & HASTRACK, PT, -1)']

#Configure Funtuple algorithm
tuple_dimuons = Funtuple(
    name="DimuonsTuple",
    tuple_name="DecayTree",
    fields=fields,
    variables=variables,
    loki_preamble=loki_preamble,
    inputs=dimuons)


def main():
    tools = []
    algs = upfront_reconstruction() + [tuple_dimuons]
    return algs, tools
