###############################################################################
# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
"""
Read an HLT2 file and create an ntuple with the new DaVinci runned with gaudirun.py script.
"""
import Functors as F
from FunTuple import FunctorCollection
from FunTuple import FunTuple_Particles as Funtuple
from PyConf.application import make_data_with_FetchDataFromFile
from DaVinci.Configuration import run_davinci_app
from DaVinci.reco_objects import make_pvs_for
from DaVinci.algorithms import add_filter
from DaVinci import options

fields = {
    "D0": "[D0 -> K- pi+]CC",
    "Kminus": "[D0 -> ^K- pi+]CC",
    "piplus": "[D0 -> K- ^pi+]CC",
}

# Creating v2 reconstructed vertices to be used in the following functor
v2_pvs = make_pvs_for(process='Hlt2', data_type="Upgrade")
d0_variables = FunctorCollection({
    "PT": F.PT,
    "BPVDIRA": F.BPVDIRA(v2_pvs),
    "BPVFDCHI2": F.BPVFDCHI2(v2_pvs),
    "BPVIPCHI2": F.BPVIPCHI2(v2_pvs)
})

daughter_variables = FunctorCollection({
    "PT": F.PT,
})

variables = {
    "D0": d0_variables,
    "Kminus": daughter_variables,
    "piplus": daughter_variables
}


def main():
    d02kpi_data = make_data_with_FetchDataFromFile(
        "/Event/HLT2/Hlt2CharmD0ToKmPipLine/Particles")

    my_filter = add_filter("HDRFilter_D0Kpi",
                           "HLT_PASS('Hlt2CharmD0ToKmPipLineDecision')")
    my_tuple = Funtuple(
        name="Tuple",
        tuple_name="DecayTree",
        fields=fields,
        variables=variables,
        inputs=d02kpi_data)

    return {"UserAlgs": [my_filter, my_tuple]}, []


options.ntuple_file = "tuple_D0_Kpi_10evts_gaudirun.root"
options.annsvc_config = "root://eoslhcb.cern.ch//eos/lhcb/wg/dpa/wp3/NovemberFEST/hlt2_D0_Kpi_10evts.tck.json"
options.process = 'Hlt2'
options.input_raw_format = 0.3
options.user_algorithms = "$DAVINCIEXAMPLESROOT/python/DaVinciExamples/tupling/option_davinci_tupling_from_hlt2_gaudirun:main"
options.write_fsr = False

fileDB_key = "FEST_November_2021_dst"
fileDB_path = "$DAVINCIROOT/options/DaVinciDB-Example.yaml"
run_davinci_app(fileDB_key, fileDB_path)
