###############################################################################
# (c) Copyright 2000-2021 CERN for the benefit of the LHCb Collaboration      #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
from GaudiTest import LineSkipper
from GaudiConf.QMTest.LHCbTest import BlockSkipper
from GaudiConf.QMTest.LHCbExclusions import preprocessor as LHCbPreprocessor

remove_uninteresting_lines = LineSkipper(regexps=[
    r"IODataManager +ERROR Referring to existing dataset",
    r"EventSelector +INFO Stream:EventSelector.DataStreamTool.*",
    r"MagneticFieldSvc +INFO Map scaled by factor",
    r"MagneticFieldSvc +INFO Opened magnetic field file",
    r"ConfigTarFileAccessSvc +INFO  opening",
    r"(Memory for the event|Mean 'delta-memory') exceeds 3*sigma",
    r"(AfterMagnet|Magnet|BeforeMagnet|Downstream)Region/.*",
    r"(LHCBCOND_|SIMCOND|DDDB)_", r"DataOnDemandSvc +INFO Handled",
    r"HLTControlFlowMgr +INFO", r"FunctorFactory +INFO Reusing cling compiled",
    r"<module .*", "SUCCESS Exceptions/Errors/Warnings/Infos Statistics :",
    "INFO MuonIDAlg v", "DaVinciInitAlg.DaVinciMemory",
    "mc_unpackers' must run BEFORE 'unpackers'", "MD5 sum:"
])

# Remove known warnings from the references
remove_known_warnings = LineSkipper(regexps=[
    # expected WARNINGs from the data broker
    r"HiveDataBrokerSvc +WARNING non-reentrant algorithm: .*",
    # Until tck is implemented HltPackedDataDecoder/HltDecReportsDecoder will raise warning
    r"HltPackedDataDecoder +WARNING TCK in rawbank seems to be 0 .*",
    r"HltPackedDataDe...WARNING TCK in rawbank seems to be 0 .*",
    r"HltDecReportsDecoder +WARNING TCK obtained from rawbank seems to be 0 .*",
    r"HLT2 +WARNING TCK obtained from rawbank seems to be 0 .*",
    r"Hlt2DecReports +WARNING TCK obtained from rawbank seems to be 0 .*",
    r"SpruceDecReports +WARNING TCK obtained from rawbank seems to be 0 .*",
    r"Spruce +WARNING TCK obtained from rawbank seems to be 0 .*",
    # Until MC tools become functional, MC tools will run but the output is nonsense
    "WARNING: MC tools not functional yet outside Hlt2 - .*",
    # FunTuple warning for the update_counters: skipping event is no candidates are found
    r"[a-zA-Z0-9]* +WARNING FunTupleBase<KeyedContainer<LHCb::MCParticle,Containers::KeyedObjectManager<Containers::hashmap> > >:: .*",
    r"FunctorFactory\s{1,}INFO Cache miss for functor: .*"
])

# Remove all DV options to avoid test failures due to LHCb changes.
# A dedicated python unit test is added in DaVinciTests.
#remove_options = LineSkipper(regexps=[r" |- .*" ])
remove_list_options = BlockSkipper(
    "/***** User DVAppOptions/DVAppOptions",
    "\\----- (End of User DVAppOptions/DVAppOptions)")

preprocessor = LHCbPreprocessor + remove_uninteresting_lines + remove_list_options + remove_known_warnings
