###############################################################################
# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
"""
Test of functors
"""
from GaudiKernel.SystemOfUnits import MeV

import Functors as F
from Functors.math import in_range
from PyConf.Algorithms import ParticleRangeFilter, TwoBodyCombiner

from DaVinci.common_particles import make_long_kaons


def make_tight_d2kk():
    """
    Make tight D->KK
    """
    kaons = make_long_kaons()
    descriptor = "D0 -> K+ K-"
    #   todo : add a ADAMASS-like cut
    combination_code = (F.DOCACHI2(1, 2) < 30) & in_range(
        1764 * MeV, F.MASS, 1964 * MeV)
    vertex_code = F.CHI2DOF < 30

    print("### Kaons are {0}".format(kaons))

    filtered_kaons = ParticleRangeFilter(
        Input=kaons, Cut=F.FILTER(F.PROBNN_K > 0.5))
    p = TwoBodyCombiner(
        name="TightD02KK",
        Input1=filtered_kaons,
        Input2=filtered_kaons,
        DecayDescriptor=descriptor,
        CombinationCut=combination_code,
        ParticleCombiner="ParticleVertexFitter",
        CompositeCut=vertex_code).OutputParticles

    print("### Returning {0}".format(p))
    return p


__author__ = "Patrick Koppenburg"
__date__ = "2021-04-28"

from PyConf.application import configure, configure_input
from PyConf.control_flow import CompositeNode, NodeLogic
from PyConf.Algorithms import PrintDecayTree

from DaVinci import options
from DaVinci.reco_objects import upfront_reconstruction_from_file as upfront_reconstruction
from DaVinci.common_particles import make_std_loose_d2kk

options.evt_max = -1
options.print_freq = 1
options.msg_svc_format = "% F%60W%S%7W%R%T %0W%M"

vd0s = make_std_loose_d2kk()
td0s = make_tight_d2kk()

print("### vD0s {0} and tD0s {1}".format(vd0s, td0s))

pdt = PrintDecayTree(name="PrintD0s", Input=vd0s)  # keyed container
pdt2 = PrintDecayTree(name="PrintTightD0s", Input=td0s)

# the "upfront_reconstruction" is what unpacks reconstruction objects, particles and primary vertices
# from file and creates protoparticles.
algs = upfront_reconstruction() + [vd0s, pdt, td0s, pdt2]

node = CompositeNode(
    "PrintD0Node", children=algs, combine_logic=NodeLogic.NONLAZY_OR)

# File from Moore test
options.set_input_and_conds_from_testfiledb("Moore-Output-DST")

config = configure_input(options)
config.update(configure(options, node))
