###############################################################################
# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
"""
Test for the function returning DataHandle for v2 RecVertices for usage in ThOr functors
"""
import Functors as F
from FunTuple import FunctorCollection
from FunTuple import FunTuple_Particles as Funtuple
from PyConf.application import make_data_with_FetchDataFromFile
from DaVinci.reco_objects import make_pvs_for
from DaVinci.algorithms import add_filter
from DaVinci import options

bd2dsk_line = "SpruceB2OC_BdToDsmK_DsmToHHH_FEST_Line"
bd2dsk_data = make_data_with_FetchDataFromFile(
    f"/Event/Spruce/{bd2dsk_line}/Particles")
fields_dsk = {
    'B0': "[B0 -> D_s- K+]CC",
}

options.ntuple_file = "test_recVertices.root"


def alg_config():
    v2_pvs = make_pvs_for(process=options.process, data_type=options.data_type)
    variables_pvs = FunctorCollection({
        "BPVDIRA": F.BPVDIRA(v2_pvs),
        "BPVFDCHI2": F.BPVFDCHI2(v2_pvs),
        "BPVIPCHI2": F.BPVIPCHI2(v2_pvs)
    })

    variables_dsk = {
        'B0': variables_pvs,
    }

    my_filter = add_filter("HDRFilter_B0DsK",
                           f"HLT_PASS('{bd2dsk_line}Decision')")
    my_tuple = Funtuple(
        name="B0DsK_Tuple",
        tuple_name="DecayTree",
        fields=fields_dsk,
        variables=variables_dsk,
        inputs=bd2dsk_data)

    return {"UserAlgs": [my_filter, my_tuple]}, []
