###############################################################################
# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
from Configurables import (DaVinci, LHCbApp, EventSelector,
                           HistogramPersistencySvc)
from Gaudi.Configuration import FileCatalog
from DaVinci.compat.tests.params import prod_conf_params


def dressInputFileNames(name):
    """Small helper to decorate the input file names."""
    if name.endswith(".raw"):
        return "DATAFILE='%s' SVC='LHCb::MDFSelector'" % name
    return "DATAFILE='%s' TYP='POOL_ROOTTREE' OPT='READ'" % name


### The common part defined in ProdConf.__apply_configuration__()

# common configuration
app = LHCbApp()

# Propagate options to LHCbApp, if set.
app.CondDBtag = prod_conf_params["CondDBTag"]
app.DDDBtag = prod_conf_params["DDDBTag"]
app.EvtMax = prod_conf_params["NOfEvents"]
app.TimeStamp = True
app.XMLSummary = prod_conf_params["XMLSummaryFile"]

HistogramPersistencySvc(OutputFile=prod_conf_params["HistogramFile"])
FileCatalog(Catalogs=["xmlcatalog_file:" + prod_conf_params["XMLFileCatalog"]])

EventSelector().Input = [
    dressInputFileNames(f) for f in prod_conf_params["InputFiles"]
]

dv = DaVinci()
