###############################################################################
# (c) Copyright 2021 CERN for the benefit of the LHCb Collaboration           #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################

# Definitions of, and defaults for, the DaVinci application options.

__optsDict__ = {
    "annsvc_config": {
        "text":
        '"""Path to .json file containing HLT2 and Spruce configuration generated by ANNSvc when the .dst input file was created. Default = ."""',
        "value":
        ''
    },
    "auditors": {
        "text":
        '"""List of auditors to run. Possible common choices include "NameAuditor", "MemoryAuditor", "ChronoAuditor". See Gaudi manual for a full list. Default = []."""',
        "value": []
    },
    "buffer_events": {
        "text":
        '"""Number of events to pre-fetch if use_iosvc=True. Default = 20000 is reasonable for most machines; it might need to be increased for more modern/powerful machines."""',
        "value":
        20000
    },
    "callgrind_profile": {
        "text": '"""Enable callgrind profiling. Default = False."""',
        "value": False
    },
    "conddb_tag": {
        "text": '"""Tag for the CondDB. Default = ."""',
        "value": ''
    },
    "control_flow_file": {
        "text":
        '"""Control flow file name (.gv extension since default output format for the DOT language). Default = '
        ' for no file generation."""',
        "value":
        ''
    },
    "data_flow_file": {
        "text":
        '"""Data flow file name (.gv extension since default output format for the DOT language). Default = '
        ' for no file generation."""',
        "value":
        ''
    },
    "data_type": {
        "text": '"""Data type, can be ["Upgrade"]. Default = ."""',
        "value": ''
    },
    "dddb_tag": {
        "text":
        '""" Data type, can be ["Upgrade"] Forwarded to PhysConf, AnalysisConf, DstConf and LHCbApp. Default = ."""',
        "value":
        ''
    },
    "detectors": {
        "text":
        '"""List of detectors. Default = [VP, UT, FT, Rich1Pmt, Rich2Pmt, Ecal, Hcal, Muon, Magnet, Tr]."""',
        "value": [
            'VP', 'UT', 'FT', 'Rich1Pmt', 'Rich2Pmt', 'Ecal', 'Hcal', 'Muon',
            'Magnet', 'Tr'
        ]
    },
    "dqflags_tag": {
        "text":
        '"""Tag for DQFLAGS. Default as set in DDDBConf for DataType. Default = ."""',
        "value":
        ''
    },
    "enable_unpack": {
        "text":
        '"""Explicitly enable/disable unpacking for input data (if specified). Default = True."""',
        "value":
        True
    },
    "event_store": {
        "text":
        '"""Event store service to be used in the job, can be HiveWhiteBoard or EvtStoreSvc (faster). Default = HiveWhiteBoard."""',
        "value":
        'HiveWhiteBoard'
    },
    "evt_pre_filters": {
        "text":
        '"""Set of event filtering algorithms to be run before DaVinci initializaton sequence. Only events passing these filters will be processed. Default = {}."""',
        "value": {}
    },
    "evt_max": {
        "text":
        '"""Number of events to analyse. Default = -1 to run over all events."""',
        "value":
        -1
    },
    "first_evt": {
        "text": '"""First event to be processed in the job. Default = 0. """',
        "value": 0
    },
    "histo_file": {
        "text": '"""Name of output histogram file. Default = '
        '."""',
        "value": ''
    },
    "ignore_dq_flags": {
        "text":
        '"""If False, process only events with good DQ. Default = False."""',
        "value":
        False
    },
    "input_files": {
        "text": '"""Input data. Default = []."""',
        "value": []
    },
    "input_raw_format": {
        "text":
        '"""Sets the expected raw input format. Default = 0.3.'
        ' (definitions at https://gitlab.cern.ch/lhcb-datapkg/RawEventFormat/blob/master/python/RawEventFormat/__init__.py)"""',
        "value":
        0.3
    },
    "input_type": {
        "text":
        '"""Type of input files, e.g. "DST", "DIGI", "RDST", "MDST", "XDST" or "LDST". Default = DST."""',
        "value":
        'DST'
    },
    "log_file": {
        "text":
        '"""Logger used to print warning and error messages. Default = ."""',
        "value":
        ''
    },
    "lumi": {
        "text": '"""Luminosity accounting. Default = False."""',
        "value": False
    },
    "main_options": {
        "text": '"""Main option file to execute. Default = ."""',
        "value": ''
    },
    "memory_pool_size": {
        "text":
        '"""Estimated size of the per-event memory pool. Set to 0 to disable the pool. Default = 10 * 1024 * 1024."""',
        "value":
        10 * 1024 * 1024
    },
    "merge_genfsr": {
        "text":
        '"""Flags whether to merge the generator-level FSRs. Default = False."""',
        "value":
        False
    },
    "monitoring_file": {
        "text": '"""Name of output monitoring file. Default = ."""',
        "value": ''
    },
    "msg_svc_format": {
        "text":
        '"""MessageSvc output format. Default = "% F%35W%S %7W%R%T %0W%M"."""',
        "value":
        '% F%35W%S %7W%R%T %0W%M'
    },
    "msg_svc_time_format": {
        "text":
        '"""MessageSvc time format. Default = "%Y-%m-%d %H:%M:%S UTC"."""',
        "value":
        '%Y-%m-%d %H:%M:%S UTC'
    },
    "n_event_slots": {
        "text":
        '"""Number of event slots. Default = -1, i.e. 1.2 * n_threads. """"',
        "value":
        -1
    },
    "n_threads": {
        "text": '"""Multithreading processing. Default = 1."""',
        "value": 1
    },
    "ntuple_file": {
        "text": '"""Name of output ntuple file. Default = '
        '."""',
        "value": ''
    },
    "output_file": {
        "text": '"""Name of the output file. Default = ."""',
        "value": ''
    },
    "output_level": {
        "text":
        '"""Set the output level used in the job. Default = INFO=3."""',
        "value": 3
    },
    "output_type": {
        "text":
        '"""Type of the output file, e.g. ROOT, DST. Default = ROOT """',
        "value": "ROOT"
    },
    "override_data_options": {
        "text":
        '"""Allow overriding default data options defined in DaVinci Database. Default = False."""',
        "value":
        False
    },
    "phoenix_filename": {
        "text":
        '"""Define the file where phoenix event data are writen. Defaults =, i.e. no phoenix output',
        "value":
        ''
    },
    "print_freq": {
        "text":
        '"""Frequency at which to print event numbers. Default = 1000."""',
        "value":
        1000
    },
    "process": {
        "text":
        '"""Process is Turbo or Spruce (and temporarily Hlt2). Default = Spruce."""',
        "value":
        'Spruce'
    },
    "python_logging_level": {
        "text": '"""Python logger level. Default = logging.WARNING=30."""',
        "value": 30
    },
    "root_compression_level": {
        "text": '"""ROOT Compression level for ntuples. Default = LZMA:6."""',
        "value": 'LZMA:6'
    },
    "scheduler_legacy_mode": {
        "text":
        '"""If false scheduler calls Algorithm::execute instead of Algorithm::sysExecute, which breaks some non-functional algorithms. Default = True."""',
        "value":
        True
    },
    "skip_events": {
        "text":
        '"""Number of events to skip at the beginning. Default = 0."""',
        "value": 0
    },
    "simulation": {
        "text": '"""Boolean to specify simulated samples. Default = False."""',
        "value": False
    },
    "stream": {
        "text":
        '"""Stream selection line belongs to - drives location of RawEvent only. Default = default."""',
        "value":
        'default'
    },
    "user_algorithms": {
        "text": '"""User algorithm to run. Default = '
        '."""',
        "value": ''
    },
    "use_iosvc": {
        "text":
        '"""Use an alternative, faster, IIOSvc implementation for MDFs. Default = False."""',
        "value":
        False
    },
    "write_fsr": {
        "text": '"""Flags whether to write out an FSR. Default = True."""',
        "value": True
    }
}
