###############################################################################
# (c) Copyright 2021-2022 CERN for the benefit of the LHCb Collaboration      #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
import pytest
from DaVinci import options


def test_option_set():
    """
    Check if it's possible to access directly to an option if set.
    """
    print(options.detectors)


def test_option_unset():
    """
    Check that it's impossible to access to an option if it has not been set.
    """
    with pytest.raises(AttributeError):
        print(options.evt_max)


def test_option_get_after_set():
    """
    Check that after assigning a value the option can be accessed correctly.
    """
    options.evt_max = 1
    print(options.evt_max)


def test_option_unknown():
    """
    Check that it's impossible to access to an unknow option.
    """
    with pytest.raises(AttributeError):
        print(options.unknown)


def test_ApplicationOptions_consistency_with_PyConf():
    """
    Check for any difference between the options available in ApplicationOptions in PyConf and the DV options.
    """
    from PyConf.application import ApplicationOptions
    from DaVinci import options
    from DaVinci.options_default import __optsDict__ as dv_defaults
    lhcb_options = ApplicationOptions.getDefaultProperties()
    dv_options = options.getDefaultProperties()
    for name, _ in lhcb_options.items():
        # Exclude Moore-specific options since they will be moved into a
        # dedicated Moore-specific ApplicationOptions class.
        if name not in ["lines_maker", "tck"]:
            assert name in dv_options, f"Option {name} not available in DaVinci"
            assert name in dv_defaults, f"Option {name} doesn't have a default value in DaVinci"
