###############################################################################
# (c) Copyright 2022 CERN for the benefit of the LHCb Collaboration           #
#                                                                             #
# This software is distributed under the terms of the GNU General Public      #
# Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
#                                                                             #
# In applying this licence, CERN does not waive the privileges and immunities #
# granted to it by virtue of its status as an Intergovernmental Organization  #
# or submit itself to any jurisdiction.                                       #
###############################################################################
import pytest
from DaVinci.optionChecker import option_checker, DVOptionError, DVKeyError


def test_get_allowed_values_for_known_option():
    """
    Check if DaVinci raises an error if the data_type is not allowed.
    """
    opt_name = "data_type"
    opt_value = "2018"
    with pytest.raises(DVOptionError):
        option_checker(opt_name, opt_value)


def test_get_allowed_values_for_unknown_option():
    """
    Check that DaVinci raise an error if checking allowed values on an unknown option.
    """
    opt_name = "data"
    opt_value = "2018"

    with pytest.raises(DVKeyError) as excinfo:
        option_checker(opt_name, opt_value)

    assert f"There is no option named '{opt_name}' in DaVinci!" in str(
        excinfo.value)


def test_get_allowed_values_for_unrestricted_option():
    """
    Check that DaVinci does't raise an error if not allowed values are expected for a given option.
    """
    opt_name = "evt_max"
    opt_value = "200"
    option_checker(opt_name, opt_value)
